@@ -180,15 +180,10 @@
     return(result)
 }
 
-.common_get_period_from_data <- function(data, locality_id, logger_index) {
-    if(.common_is_agg_format(data)) {
-        if(data$metadata@period %in% .agg_const_INTERVAL_PERIODS) {
-            return(lubridate::as.period(data$metadata@intervals))
-        }
-        return(data$metadata@period)
+.common_get_period_from_agg_data <- function(data) {
+    if(data$metadata@period %in% .agg_const_INTERVAL_PERIODS) {
+        return(lubridate::as.period(data$metadata@intervals))
     }
-
-    step <- data$localities[[locality_id]]$loggers[[logger_index]]$clean_info@step
-    return(lubridate::seconds_to_period(step))
+    return(data$metadata@period)
 }
 
