@@ -113,6 +113,11 @@ mc_load <- function(file) {
 }
 
 .serialize_edit_logger_list_before_load <- function(item, original_version) {
+    if(original_version < "1.1.0") {
+        if(item$metadata$type == "HOBO") {
+            item$metadata$type <- .model_const_LOGGER_HOBO_U23_001A
+        }
+    }
     if(original_version < "1.0.6") {
         if(item$metadata$type %in% names(.serialize_MAP_1_0_6$loggers)) {
             item$metadata$type <- .serialize_MAP_1_0_6$loggers[[item$metadata$type]]
